@@ -45,8 +45,8 @@ Puppet::Type.newtype(:panko_api_paste_ini) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do
-    'panko'
+  autorequire(:anchor) do
+    ['panko::install::end']
   end
 
 end
