@@ -1,34 +1,24 @@
-require 'spec_helper'
-# this hack is required for now to ensure that the path is set up correctly
-# to retrive the parent provider
-$LOAD_PATH.push(
-  File.join(
-    File.dirname(__FILE__),
-    '..',
-    '..',
-    'fixtures',
-    'modules',
-    'inifile',
-    'lib')
-)
+require 'puppet'
 require 'puppet/type/panko_api_paste_ini'
+
 describe 'Puppet::Type.type(:panko_api_paste_ini)' do
   before :each do
     @panko_api_paste_ini = Puppet::Type.type(:panko_api_paste_ini).new(:name => 'DEFAULT/foo', :value => 'bar')
   end
+
   it 'should accept a valid value' do
     @panko_api_paste_ini[:value] = 'bar'
     expect(@panko_api_paste_ini[:value]).to eq('bar')
   end
 
-  it 'should autorequire the package that install the file' do
+  it 'should autorequire the anchor that install the file' do
     catalog = Puppet::Resource::Catalog.new
-    package = Puppet::Type.type(:package).new(:name => 'panko')
-    catalog.add_resource package, @panko_api_paste_ini
+    anchor = Puppet::Type.type(:anchor).new(:name => 'panko::install::end')
+    catalog.add_resource anchor, @panko_api_paste_ini
     dependency = @panko_api_paste_ini.autorequire
     expect(dependency.size).to eq(1)
     expect(dependency[0].target).to eq(@panko_api_paste_ini)
-    expect(dependency[0].source).to eq(package)
+    expect(dependency[0].source).to eq(anchor)
   end
 
 end
